@@ -14,8 +14,7 @@ geoserver_down <- !(check_geoserver(timeout = 5, quiet = TRUE))
 
 test_that("get_metadata works", {
   skip_if_offline()
-  skip_on_cran()
-  skip_if(geoserver_down)
+  skip_if(geoserver_down, message = "VicmapR geoserver not currently available")
   
   r <- get_metadata(vicmap_query(layer = "open-data-platform:hy_watercourse"))
   
@@ -33,8 +32,7 @@ test_that("get_metadata works", {
 
 test_that("data_dictionary works", {
   skip_if_offline()
-  skip_on_cran()
-  skip_if(geoserver_down)
+  skip_if(geoserver_down, message = "VicmapR geoserver not currently available")
   
   r <- data_dictionary(vicmap_query(layer = "open-data-platform:apiary"))
   
@@ -44,11 +42,10 @@ test_that("data_dictionary works", {
 
 test_that("data_citation works", {
   skip_if_offline()
-  skip_on_cran()
-  skip_if(geoserver_down)
+  skip_if(geoserver_down, message = "VicmapR geoserver not currently available")
   
   data_citation(vicmap_query(layer = "open-data-platform:basins"))
   
   expect_output({data_citation(vicmap_query(layer = "open-data-platform:basins"))})
   
-})
\ No newline at end of file
+})
